"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "Client", {
  enumerable: true,
  get: function () {
    return _elasticsearch.Client;
  }
});
Object.defineProperty(exports, "ClientOptions", {
  enumerable: true,
  get: function () {
    return _elasticsearch.ClientOptions;
  }
});
exports.createElasticsearchClient = void 0;
var _awsElasticsearchConnector = _interopRequireDefault(require("aws-elasticsearch-connector"));
var _crypto = _interopRequireDefault(require("crypto"));
var _error = _interopRequireDefault(require("@webiny/error"));
var _elasticsearch = require("@elastic/elasticsearch");
const clients = new Map();
const createClientKey = options => {
  const key = JSON.stringify(options);
  const hash = _crypto.default.createHash("sha1");
  hash.update(key);
  return hash.digest("hex");
};
const createElasticsearchClient = options => {
  const key = createClientKey(options);
  const existing = clients.get(key);
  if (existing) {
    return existing;
  }
  const cached = () => {
    const {
      endpoint,
      node,
      ...rest
    } = options;
    let clientOptions = {
      node: endpoint || node,
      ...rest
    };
    if (!clientOptions.auth) {
      const region = String(process.env.AWS_REGION);
      const credentials = {
        accessKeyId: process.env.AWS_ACCESS_KEY_ID,
        secretAccessKey: process.env.AWS_SECRET_ACCESS_KEY,
        sessionToken: process.env.AWS_SESSION_TOKEN
      };
      const errors = Object.keys(credentials).filter(key => {
        const value = credentials[key];
        return !value;
      });
      if (errors.length > 0) {
        throw new _error.default(`Missing keys values: ${errors.join(", ")}`, "MISSING_AWS_CREDENTIALS");
      }
      clientOptions = {
        ...clientOptions,
        ...(0, _awsElasticsearchConnector.default)({
          region,
          // @ts-expect-error
          credentials
        })
      };
    }
    try {
      return new _elasticsearch.Client(clientOptions);
    } catch (ex) {
      const data = {
        error: ex,
        node: endpoint || node,
        ...rest,
        auth: undefined
      };
      console.error({
        ...data
      });
      throw new _error.default("Could not connect to Elasticsearch.", "ELASTICSEARCH_CLIENT_ERROR", data);
    }
  };
  const client = cached();
  clients.set(key, client);
  return client;
};
exports.createElasticsearchClient = createElasticsearchClient;

//# sourceMappingURL=client.js.map