"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ElasticsearchQueryBuilderOperatorBetweenPlugin = void 0;
var _ElasticsearchQueryBuilderOperatorPlugin = require("../definition/ElasticsearchQueryBuilderOperatorPlugin");
class ElasticsearchQueryBuilderOperatorBetweenPlugin extends _ElasticsearchQueryBuilderOperatorPlugin.ElasticsearchQueryBuilderOperatorPlugin {
  name = "elasticsearch.queryBuilder.operator.between.default";
  getOperator() {
    return "between";
  }
  apply(query, params) {
    const {
      value,
      basePath,
      name
    } = params;
    if (Array.isArray(value) === false) {
      throw new Error(`You cannot filter field path "${name}" with between query and not send an array of values.`);
    } else if (value.length !== 2) {
      throw new Error(`You must pass 2 values in the array for field path "${name}" filtering.`);
    }
    // we take gte first because it should be a lesser value than lte, eg [5, 10]
    // 6 >= gte && 6 <= lte
    const [gte, lte] = value;
    query.filter.push({
      range: {
        [basePath]: {
          lte,
          gte
        }
      }
    });
  }
}
exports.ElasticsearchQueryBuilderOperatorBetweenPlugin = ElasticsearchQueryBuilderOperatorBetweenPlugin;

//# sourceMappingURL=between.js.map